import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql/index.js';
import { debug } from './debug.js';
import { getAllDeviceInfo } from './get-all-device-info.js';
/**
  * Gets serial operations to insert Device
  *
  * @example
 ```ts
 const serialOperations = await makeDeviceInsertOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function makeDeviceInsertOperations(options) {
    const log = debug(makeDeviceInsertOperations.name);
    log({ Options: options });
    const { info = await getAllDeviceInfo(), containerLinkId, } = options;
    log({ info });
    const { containValue } = options;
    const reservedLinkIds = await this.reserve(2);
    log({ reservedLinkIds });
    const deviceLinkId = options.reservedLinkIds?.deviceLinkId ?? reservedLinkIds.pop();
    log({ deviceLinkId });
    const containLinkId = options.reservedLinkIds?.containLinkId ?? reservedLinkIds.pop();
    log({ containLinkId });
    const operations = [
        createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                id: deviceLinkId,
                type_id: this.capacitorDevicePackage.Device.idLocal(),
            },
        }),
        createSerialOperation({
            type: 'insert',
            table: 'objects',
            objects: {
                link_id: deviceLinkId,
                value: info,
            }
        }),
        createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                id: containLinkId,
                type_id: this.idLocal("@deep-foundation/core", "Contain"),
                from_id: containerLinkId || this.linkId,
                to_id: deviceLinkId,
                ...(containValue ? { value: containValue } : {})
            }
        })
    ];
    log({ operations });
    return {
        operations,
        deviceLinkId,
        containLinkId,
    };
}
