/**
 * A higher-order component that handles the logic of inserting a device link into Deep if it does not exist and saving device information.
 *
 * @remarks
 * This component uses the custom hook {@link useDeviceSync}
 *
 * @returns The result of {@link WithDeviceSyncOptions.renderIfLoading} if the synchronization is in the process, or the result of {@link WithDeviceSyncOptions.renderChildren} if synchronization is done.
 */
export function WithDeviceSync(options) {
    const { children, renderIfLoading, deep } = options;
    const { isLoading } = deep.useDeviceSync(options);
    if (isLoading) {
        return renderIfLoading();
    }
    return children;
}
