import { useState, useEffect } from "react";
import { packageLog } from "../../package-log.js";
export function useDeviceLink(options) {
    const log = packageLog.extend(useDeviceLink.name);
    log({ options });
    const { initialDeviceLinkId, deep, containerLinkId = deep.linkId, shouldAct = true, } = options;
    const [deviceLinkId, setDeviceLinkId] = useState(initialDeviceLinkId);
    log({ deviceLinkId });
    const [isLoading, setIsLoading] = useState(undefined);
    log({ isLoading, setIsLoading });
    const [error, setError] = useState(undefined);
    log({ error, setError });
    useEffect(() => {
        if (!shouldAct)
            return;
        new Promise(async () => {
            setIsLoading(true);
            log(`setIsLoading(true)`);
            setError(null);
            log(`setError(null)`);
            try {
                let deviceLink;
                if (deviceLinkId) {
                    deviceLink = await deep
                        .select(deviceLinkId)
                        .then((result) => result.data[0]);
                }
                log({ deviceLink });
                if (!deviceLink) {
                    const { deviceLinkId: newDeviceLinkId } = await deep.insertDevice({
                        containerLinkId,
                    });
                    log({ newDeviceLinkId });
                    setDeviceLinkId(newDeviceLinkId);
                }
            }
            catch (error) {
                log({ error });
                setError(error);
            }
            finally {
                setIsLoading(false);
            }
        });
    }, [initialDeviceLinkId, shouldAct]);
    return {
        deviceLinkId,
        isLoading,
        error,
    };
}
