import { useEffect, useState } from "react";
import { packageLog } from "../../package-log.js";
const moduleLog = packageLog.extend("react/hooks/use-device-sync.ts");
/**
 * A custom React Hook that checks if a device link exists in the Deep database, and if not, it inserts one
 */
export function useDeviceSync(options) {
    const log = moduleLog.extend(useDeviceSync.name);
    log({ options });
    const { deviceLinkId: deviceLinkId, deep } = options;
    const [isLoading, setIsLoading] = useState(undefined);
    log({ isLoading, setIsLoading });
    const [error, setError] = useState(undefined);
    log({ error, setError });
    useEffect(() => {
        setIsLoading(true);
        deep
            .updateDevice({
            deviceLinkId: deviceLinkId,
        })
            .then(() => {
            setIsLoading(false);
        })
            .catch(setError);
    }, [deviceLinkId]);
    return { isLoading, error };
}
